@@ -38,6 +38,7 @@ class JijSASampler(JijCloudSampler, JijModelSamplerInterface, JijModelingInterfa
                      feed_dict=None,
                      search=None,
                      max_iter=5,
+                     alpha=1.0,
                      beta_min=None, beta_max=None,
                      num_reads=1, mc_steps=100,
                      timeout=None
@@ -66,6 +67,7 @@ class JijSASampler(JijCloudSampler, JijModelSamplerInterface, JijModelingInterfa
                                     feed_dict=feed_dict,
                                     search=search,
                                     max_iter=max_iter,
+                                    alpha=alpha,
                                     beta_min=beta_min, beta_max=beta_max,
                                     num_reads=num_reads, mc_steps=mc_steps,
                                     timeout=timeout)
