@@ -7,7 +7,7 @@ class JijSQASampler(JijCloudSampler, JijModelSamplerInterface):
     algorithm = 'sqa'
 
     def sample(self, bqm, beta=1.0, gamma=1.0, trotter=4,
-               num_reads=1, mc_steps=100):
+               num_reads=1, mc_steps=100, timeout=None):
         """sample ising
         Args:
             bqm (:obj:`dimod.BinaryQuadraticModel`): Binary quadratic model.
@@ -16,6 +16,7 @@ class JijSQASampler(JijCloudSampler, JijModelSamplerInterface):
             trotter (int, optional): number of trotter slices. should be even.
             num_reads (int, optional): number of samples. Defaults to 1.
             mc_steps (int, optional): number of MonteCarlo steps
+            timeout (float, optional): number of timeout for post request. Defaults to None.
 
         Returns:
             dimod.SampleSet: store minimum energy samples
@@ -29,5 +30,6 @@ class JijSQASampler(JijCloudSampler, JijModelSamplerInterface):
 
         return super().sample(
             bqm, num_reads, mc_steps,
-            gamma=gamma, trotter=trotter, beta=1.0
+            gamma=gamma, trotter=trotter, beta=1.0, 
+            timeout=timeout
         )
