@@ -6,7 +6,7 @@ class JijGPUSQASampler(JijCloudSampler):
     algorithm = 'sqa'
 
     def sample(self, bqm, beta=1.0, gamma=1.0, trotter=4,
-               num_reads=1, mc_steps=100):
+               num_reads=1, mc_steps=100, timeout=None):
         """sample ising
         Args:
             bqm (:obj:`dimod.BinaryQuadraticModel`): Binary quadratic model.
@@ -15,6 +15,7 @@ class JijGPUSQASampler(JijCloudSampler):
             trotter (int, optional): number of trotter slices. should be even.
             num_reads (int, optional): number of samples. Defaults to 1.
             mc_steps (int, optional): number of MonteCarlo steps
+            timeout (float, model): number of timeout for post request. Defaults to None.
 
         Returns:
             dimod.SampleSet: store minimum energy samples
@@ -28,5 +29,6 @@ class JijGPUSQASampler(JijCloudSampler):
 
         return super().sample(
             bqm, num_reads, mc_steps,
-            gamma=gamma, trotter=trotter, beta=1.0
+            gamma=gamma, trotter=trotter, beta=1.0, 
+            timeout=timeout
         )
